aztec-nr - protocol_types::abis::private_kernel_data

Struct PrivateKernelData

pub struct PrivateKernelData {
    pub public_inputs: PrivateKernelCircuitPublicInputs,
    pub vk_data: VkData<127>,
}

Fields

public_inputs: PrivateKernelCircuitPublicInputs
vk_data: VkData<127>

Implementations

impl PrivateKernelData

pub fn validate_vk_in_vk_tree<let N: u32>(self, allowed_indices: [u32; N])

Validates that the vk hash exists in the vk tree at the expected index. Note: There's a similarly-named function in vk_data.nr. This function is different, in that it lets us set only PRIVATE_KERNEL_RESET_INDEX in the allowed_indices to allow all the reset circuits. So unfortunately we can't use the same function in vk_data.nr.

pub fn verify(self, is_last_inner_kernel: bool)